@@ -1395,7 +1395,7 @@ QString runKMail(bool minimise)
         QString errmsg;
         if (minimise  &&  Private::startKMailMinimised())
             return QString();
-        if (KToolInvocation::startServiceByDesktopName(QStringLiteral("kmail"), QString(), &errmsg))
+        if (KToolInvocation::startServiceByDesktopName(QStringLiteral("org.kde.kmail"), QString(), &errmsg))
         {
             qCCritical(KALARM_LOG) << "Couldn't start KMail (" << errmsg << ")";
             return xi18nc("@info", "Unable to start <application>KMail</application><nl/>(<message>%1</message>)", errmsg);
