@@ -20,7 +20,7 @@
 */
 
 // Use the kdepim version
-#include "kdepim-version.h"
+#include "kontact-version.h"
 
 #include "mainwindow.h"
 #include "kontact_debug.h"
@@ -38,6 +38,7 @@ using namespace Kontact;
 #include <KService>
 #include <KServiceTypeTrader>
 #include <KWindowSystem>
+#include <KCrash>
 
 #include <QCommandLineParser>
 
@@ -157,9 +158,8 @@ int main(int argc, char **argv)
 {
     KontactApp app(argc, &argv);
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-#if QT_VERSION >= 0x050600
     app.setAttribute(Qt::AA_EnableHighDpiScaling);
-#endif
+    KCrash::initialize();
     Kdelibs4ConfigMigrator migrate(QStringLiteral("kontact"));
     migrate.setConfigFiles(QStringList() << QStringLiteral("kontactrc") << QStringLiteral("kontact_summaryrc"));
     migrate.setUiFiles(QStringList() << QStringLiteral("kontactui.rc"));
