@@ -1,18 +1,20 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2016 Montel Laurent <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
 
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
 
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+   You should have received a copy of the GNU General Public License
+   along with this program; see the file COPYING.  If not, write to
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #include "exportresourcearchivejob.h"
@@ -70,7 +72,7 @@ void ExportResourceArchiveJob::start()
         connect(mThread, &PimSettingBackupThread::error, this, &ExportResourceArchiveJob::error);
         connect(mThread, &PimSettingBackupThread::info, this, &ExportResourceArchiveJob::info);
         connect(mThread, &PimSettingBackupThread::terminated, this, &ExportResourceArchiveJob::slotTerminated);
-        connect(mThread, SIGNAL(finished()), mThread, SLOT(deleteLater()));
+        connect(mThread, &QThread::finished, mThread, &QObject::deleteLater);
         mThread->start();
     } else {
         qCDebug(PIMSETTINGEXPORTERCORE_LOG) << "zip not defined !";
